# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2011. All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

import sys, re
from java.lang import System
from java.util import Properties
from java.util import Hashtable
from com.ibm.websphere.management.metadata import ManagedObjectMetadataHelper
from com.ibm.wsspi.management.metadata import ManagedObjectMetadataCollector
from com.ibm.wsspi.management.metadata import ManagedObjectMetadataCollectorImplBase
from com.ibm.wsspi.management.metadata import ManagedObjectMetadataCollectorManager
from com.ibm.wsspi.management.metadata import ManagedObjectMetadataCollectorManagerFactory
from com.ibm.wsspi.scripting import ScriptingExtensionHelper

if sys.argv[0] == "-add":
  action = ManagedObjectMetadataCollector.ACTION_ADD_EXTENSION
elif sys.argv[0] == "-remove":
  action = ManagedObjectMetadataCollector.ACTION_REMOVE_EXTENSION
else:
  action = ManagedObjectMetadataCollector.ACTION_COLLECT_METADATA

templateName = sys.argv[1] # the base name of the template path
nodeName = System.getProperty("local.node")

# determine profile level (everything after the first dot in the template name) and corresponding extension ID
if action == ManagedObjectMetadataCollector.ACTION_COLLECT_METADATA:
  extension = None
else:
  lvl2ext = { "bpm": "BPMFX", "procsvr" : "BPMPS", "procctr" : "BPMPC", "procsvr.adv" : "BPMPS", "procctr.adv" : "BPMPC" }
  match = re.match("[^\.]*\.(.*)", templateName)
  if not match:
    raise AssertionError, "Failed to parse profile level from " + `templateName` + "."
  level = match.group(1)
  if not lvl2ext.has_key(level):
    raise AssertionError, "Unknown profile level: " + `extension` + "."
  extension = lvl2ext[level]

# determine profile type (default, dmgr, managed) -- everything up to the first dot in the template name
match = re.match("([^\.]*)\.", templateName)
if not match:
  raise AssertionError, "Failed to parse profile type from " + `templateName` + "."
# Can't use the ManagedObjectMetadataCollectorImplBase.PROFILE_TYPE_* constants, they only have package visibility
profileType = match.group(1)
if profileType == "management":
  profileType = "dmgr"

print "Triggering action '%s' for extension '%s' on node %s (type %s)." % (action, extension, nodeName, profileType)

props = Properties();
props.put(ManagedObjectMetadataCollectorManager.CELL_NAME, System.getProperty("local.cell"))
props.put(ManagedObjectMetadataCollectorManager.NODE_NAME, nodeName)

# If the admin client is null, we are running in disconnected mode. Passing a 'null' admin client would cause
# the factory to search for connection properties in the config repository - we don't want that, so we use the
# one-argument constructor for the disconnected case.
adminClient = ScriptingExtensionHelper.getCurrentScriptingAdminClient();
if adminClient:
  collectorManager = ManagedObjectMetadataCollectorManagerFactory.createCollectorManager(props, adminClient)
else:
  collectorManager = ManagedObjectMetadataCollectorManagerFactory.createCollectorManager(props)

parms = Hashtable()
if action != ManagedObjectMetadataCollector.ACTION_COLLECT_METADATA:
  parms.put(ManagedObjectMetadataCollector.PARAM_EXTENSION_ID, extension)
if profileType:
  parms.put(ManagedObjectMetadataCollectorImplBase.ACTION_PARAM_PROFILE_TYPE, profileType)

props = collectorManager.updateMetadata(action, parms)

print "Installed products: %s." % props.get("com.ibm.websphere.installed.products")
print "Updated product metadata: %s." % [(key, props.get(key)) for key in props.keys() if key.endswith("ProductShortName")]
print "Updated version metadata: %s." % [(key, props.get(key)) for key in props.keys() if key.endswith("ProductVersion")]
print "Updated deployed features: %s." % props.get(ManagedObjectMetadataHelper.NODE_DEPLOYED_FEATURES)
print "Done."
