# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2007, 2008. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

# import related classes
import sys;
from java.lang import *;
import java.io.File as File;
import java.util.Properties as Properties;
import re;

#------------------------------------------------------------------------------
# get the property value by the the property name; If property not available, return ''
#------------------------------------------------------------------------------
def getPropertyValue(propertyName):
	propertyValue = java.lang.System.getProperty(propertyName);
	if(propertyValue == None):
		return '';
	return propertyValue;
#endDef

#-----------------------------------------------------------------
# Logs messages
#-----------------------------------------------------------------
def trace(message):
    print message;
#endDef

def normalizePath(pathName):
	newPath=File(pathName);
	return newPath.getAbsolutePath();
#endDef


#------------------------------------------------------------------------------
# get the cell name
#------------------------------------------------------------------------------
def getCellName():
	return getPropertyValue('local.cell');
#endDef

#------------------------------------------------------------------------------
# get the node name
#------------------------------------------------------------------------------
def getNodeName():
	return getPropertyValue('local.node');
#endDef

#------------------------------------------------------------------------------
# get the node type: managed,unmanaged,
#------------------------------------------------------------------------------
def getNodeType():
	return getPropertyValue('wbi.upgrade.node.type');
#endDef

#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getWASHome():
	return getPropertyValue('was.install.root');
#endDef


#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getProfileHome():
	return getPropertyValue('user.install.root');
#endDef

#------------------------------------------------------------------------------
# Determine if the current platform is z/OS
#------------------------------------------------------------------------------
def isZOS():
	propertyValue = java.lang.System.getProperty("os.name");
	if((propertyValue == "OS/390") or (propertyValue == "z/OS")):
		return 1
	return 0
#endDef

#--------------------------------------------------------------
# Helper Class to normalize the string for comparision
#--------------------------------------------------------------
def wsadminToList(inStr):
	outList=[]
	if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
		tmpList = inStr[1:-1].split() #splits space-separated lists,
	else:
		tmpList = inStr.split("\n")   #splits for Windows or Linux
	for item in tmpList:
		item = item.rstrip();         #removes any Windows "\r"
		if (len(item)>0):
			outList.append(item)
	return outList;
#endDef

#------------------------------------------------------------------------------
# get the scope Id according to cellname ,nodename, servername, clustername
#------------------------------------------------------------------------------
def getScopeId(cellName,nodeName,serverName,clusterName):
	trace("****************getScopeId() start****************");
	scopeId="";
	if (cellName ==''):
		scopeId='';
	elif (nodeName ==''):
		scopeId=AdminConfig.getid('/Cell:' + cellName);
	elif (serverName == '' and clusterName == ''):
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName);
	elif (serverName == ''):
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/ServerCluster:' + clusterName);
	else:
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName);
	#endIf
	trace("****************getScopeId() end****************");
	return scopeId;
#endDef

def getExactScopeId(Id,cellName,nodeName,serverName, clusterName):
	# get exact variable which is only located in  cell ,node or server or cluster level.
	filteredId="";
	if(cellName == ""):
		filteredId="";
	elif(nodeName == ""):
		filteredId=locateId(Id,"cell");
	elif(serverName == "" and clusterName == ""):
		filteredId=locateId(Id,"node");
	elif(clusterName==""):
		filteredId=locateId(Id,"server");
	else:
		filteredId=locateId(Id,"cluster");

	#endIf
	
	return filteredId;
#endDef

#---------------------------------------------------------------------------------------------------------------
# locate resource in cell , node or server level.
#---------------------------------------------------------------------------------------------------------------
def locateId(element,scopeLevel):
	if ( scopeLevel == "cell" ):
		#cell level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) == None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "node" ):
		#node level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "server" ):
		#server level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(servers).*",element) != None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "cluster" ):
		#cluster level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(clusters).*",element) != None and
			re.search(".*(nodes).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	else:
		return "";
	#endIf
#endDef

#--------------------------------------------------------------------------------------------------------------------------------------------
# get a value of  WPSHOME.that is migrated.
# main logic:
# get MigratedWASHOME from ${backupDir}/websphere_backup/properties/profileRegistry.xml file.
#---------------------------------------------------------------------------------------------------------------------------------------------
def getMigratedWASHome():
	trace("****************getMigratedWASHome() start****************");
	backupDir=getBackupDir();
	trace("wbi migration backup dir:"+backupDir);
	profileRegistryFile=backupDir+File.separator+"websphere_backup"+File.separator+"properties"+File.separator+"profileRegistry.xml";
	sourceFile=open(profileRegistryFile,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	for srcline in srclines :
		# trace(srcline);
		foundString='template="';
		foundStringLen=len(foundString);
		startIndex=srcline.find(foundString);
		if(startIndex!=-1):
			endIndex=srcline.find('">',startIndex+foundStringLen);
			templatePath=srcline[startIndex+foundStringLen:endIndex];
			trace("templatePath: "+templatePath);
			foundTemplatePathString="profileTemplates";
			templatePathStartIndex=templatePath.find(foundTemplatePathString);
			wasHome=templatePath[0:templatePathStartIndex - 1];
			trace("WASHOME: "+wasHome);
			break;
		#endIf
	#endFor
	trace("****************getMigratedWASHome() end****************");
	return wasHome;
#endDef

#--------------------------------------------------------------------------------------------------------------------------------------------
# get a value of  Profile HOME.that is migrated.
# main logic:
# get MigratedWASHOME from ${backupDir}/websphere_backup/properties/profileRegistry.xml file.
#---------------------------------------------------------------------------------------------------------------------------------------------
def getMigratedProfileHome():
	trace("****************getMigratedProfileHome() start****************");
	previousProfileName = System.getProperty("bpm.upgrade.previous.profileName");
	backupDir=getBackupDir();
	trace("wbi migration backup dir:"+backupDir);
	trace("previousProfileName " + previousProfileName);
	profileRegistryFile=backupDir+File.separator+"websphere_backup"+File.separator+"properties"+File.separator+"profileRegistry.xml";
	sourceFile=open(profileRegistryFile,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	profileHome = ""
	for srcline in srclines :
		trace(srcline);
		foundString='name="' + previousProfileName;
		foundStringLen=len(foundString);
		startIndex=srcline.find(foundString);
		if(startIndex!=-1):
			startIndex = srcline.find('path="');
			endIndex=srcline.find('"',startIndex+6);
			templatePath=srcline[startIndex+6:endIndex];
			trace("Path: "+templatePath);
			profileHome = templatePath
			trace("ProfileHOME: "+templatePath);
			break;
		#endIf
	#endFor
	trace("****************getMigratedProfileHome() end****************");
	return profileHome;
#endDef


#--------------------------------------------------------------
# Get Backup Folder for Migrtaing WPS Profile
#--------------------------------------------------------------
def getBackupDir():
	return getPropertyValue('wbi.upgrade.backup.dir');
	#return "E:\\backup601";
#endDef

#---------------------------------------------------------------------------
# convert 60x variable to 70 variable:
# for example:   
# c:/wps601/profiles/proc1 ---> c:/wps70/profiles/proc1
#----------------------------------------------------------------------------
def convertProfilePathFrom6xTo70(variable60x):
	trace("****************convertProfilePathFrom6xTo70() start****************");
	
	migratedProfileHome=normalizePath(getMigratedProfileHome());
	migratedProfileHome=migratedProfileHome.replace('\\',"/");
	trace("migratedProfileHome:"+migratedProfileHome);
	
	#the location of 61 was root home
	presentProfileHome=getProfileHome();
	#presentWPSHome=presentProfileHome.replace('\\',"/");
	trace("presentProfileHome:"+presentProfileHome);
	
	#convert a variable of 60x to  a new variable of 61.
	variable61="";
	#fix the delimiter
	variable60xnew = variable60x.replace('\\', "/");
	trace("variable60xnew:"+variable60xnew);
	if (variable60xnew.find(migratedProfileHome)!=-1):
		foundStringLenMigratedProfileHome=len(migratedProfileHome);
		#check for the variable length itself
		variablelength = len(variable60x);
		if (variablelength == foundStringLenMigratedProfileHome):
		    trace("length is matching");
		    if (migratedProfileHome == variable60xnew):
		    		trace("value is matching");
				variable61 = presentProfileHome;
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
		    else:
				variable61 = variable60x;
		    #endIf
		else:
			str = variable60xnew[0:foundStringLenMigratedProfileHome+1]
			if ( (migratedProfileHome+"/"  == str) or (migratedProfileHome+"\\"  == str)  ):
				trace("value matching found");
				variable61=variable60xnew.replace(migratedProfileHome,presentProfileHome);
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
			else: 
				variable61=variable60x;
			#endIf
		#endIf
	else:
		variable61=variable60x;
	
	#endIf
	trace("Value being returned " + variable61);
	return variable61;
#endDef

def convertPathFrom6xTo70(variable60x):
	# the location of 60x was root home 
	migratedWPSHome=normalizePath(getMigratedWASHome());
	migratedWPSHome=migratedWPSHome.replace('\\',"/");
	trace("migratedWPSHome:"+migratedWPSHome);
	
	#the location of 61 was root home
	presentWPSHome=getWASHome();
	#presentWPSHome=presentWPSHome.replace('\\',"/");
	trace("presentWPSHome:"+presentWPSHome);
	
	#convert a variable of 60x to  a new variable of 61.
	variable61="";
	#fix the delimiter
	variable60xnew = variable60x.replace('\\', "/");
	trace("variable60xnew:"+variable60xnew);
	if (variable60xnew.find(migratedWPSHome)!=-1):
		foundStringLenMigratedWPSHome=len(migratedWPSHome);
		#check for the variable length itself
		variablelength = len(variable60x);
		if (variablelength == foundStringLenMigratedWPSHome):
		    trace("length is matching");
		    if (migratedWPSHome == variable60xnew):
		    		trace("value is matching");
				variable61 = presentWPSHome;
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
		    else:
				variable61 = variable60x;
		    #endIf
		else:
			str = variable60xnew[0:foundStringLenMigratedWPSHome+1]
			if ( (migratedWPSHome+"/"  == str) or (migratedWPSHome+"\\"  == str)  ):
				trace("value matching found");
				variable61=variable60xnew.replace(migratedWPSHome,presentWPSHome);
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
			else: 
				variable61=variable60x;
			#endIf
		#endIf
	else:
		variable61=variable60x;
	#endIf
	
	trace("Value being returned " + variable61);
	trace("****************convertPathFrom6xTo70() end****************");
	return variable61;
#endDef

#-------------------------------------------------------------------------------------------------------------------------
# Updates variables in the given scope which have the 'source_install' in the value and replaces it with 'WAS_INSTALL_ROOT'
#-------------------------------------------------------------------------------------------------------------------------
def replaceOldInstallRoot (oldInstall,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	trace("****************replaceOldInstallRoot() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName + " ##clusterName:" + clusterName);
	oldInstall = oldInstall.replace("/",'\\')
	trace ("To parse for old install root value'" + oldInstall + "'");
	oldInstallWindows = oldInstall.replace('\\', "/");
	trace ("To parse for old install windows root value'" + oldInstall + "'");


	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!=""):
				variableValue = AdminConfig.showAttribute(entry, "value");
				if(variableValue != None and variableValue != '' and variableValue.find(oldInstall)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldInstallRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertPathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldInstall + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
				if(variableValue != None and variableValue != '' and variableValue.find(oldInstallWindows)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldInstallRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertPathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldInstall + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
			#endIf
		#endFor
	#endFor
trace("****************replaceOldInstallRoot() end****************");
#endDef


#-------------------------------------------------------------------------------------------------------------------------
# Updates variables in the given scope which have the 'source_install' in the value and replaces it with 'WAS_INSTALL_ROOT'
#-------------------------------------------------------------------------------------------------------------------------
def replaceOldProfileRoot (oldProfileRoot,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	trace("****************replaceOldProfileRoot() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName+ "##clusterName" + clusterName);
	oldProfileRoot = oldProfileRoot.replace("/",'\\')
	trace ("To parse for old profile root value'" + oldProfileRoot + "'");
	oldProfileRootWindows = oldProfileRoot.replace('\\', "/");
	trace ("To parse for old profile windows root value'" + oldProfileRootWindows + "'");


	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!=""):
				variableValue = AdminConfig.showAttribute(entry, "value");
				if(variableValue != None and variableValue != '' and variableValue.find(oldProfileRoot)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldProfileRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertProfilePathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldProfileRoot + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
				if(variableValue != None and variableValue != '' and variableValue.find(oldProfileRootWindows)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldProfileRootWindows value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertProfilePathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldProfileRootWindows + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
			#endIf
		#endFor
	#endFor
trace("****************replaceOldProfileRoot() end****************");
#endDef


#-----------------------------------------------------------------
# Returns  id of the environment variable
#-----------------------------------------------------------------
def getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	variableMapIds=[];
	trace("****************getVariableMapIds() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName + "##clusterName" + clusterName);
	trace ("To parse environment variable '" + variableName + "'");
	
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!="" and AdminConfig.showAttribute(entry, "symbolicName") == variableName):
				variableValue = AdminConfig.showAttribute(entry, "value");
				trace ("The value of " + variableName + " is '" + str(variableValue) + "'");
				trace ("VariableMapId:"+entry);
				variableMapIds.append(entry);
			#endIf
		#endFor
	#endFor
	trace("****************getVariableMapIds() end****************");
	return variableMapIds;
#endDef


#---------------------------------------------------------------------------------------------------------------------------------------------------------
#  set a WebSphere environment variable
#---------------------------------------------------------------------------------------------------------------------------------------------------------
def setVariableValue(variableName,variableValue,cellName,nodeName,serverName, clusterName):
	trace("****************setVariableValue() start****************");
	trace("variableName:" + variableName + " variableValue:"+str(variableValue));

	try:
		global AdminConfig;
		trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName+ "##clusterName:" + clusterName);
		trace ("##name:"+variableName+" ##value:"+str(variableValue));
		
		varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName);
		if(len(varMapIds)!=0):
			for varMap in varMapIds:
				trace ("##varMapId being modified:"+varMap + "with value " + variableValue);
				attribute=[['value', variableValue]];
				AdminConfig.modify(varMap, attribute);
				AdminConfig.save();
			#endFor
			trace("****************setVariableValue() end****************");
			return 1;
		#endIf
		trace("****************setVariableValue() end****************");
		return 0;
	except:
		print "Error during setVariableValue():", sys.exc_info();
		trace("****************setVariableValue() end****************");
		return 0;
	#endTry
#endDef

def updateDB2Variables(cellName, nodeName, serverName, clusterName):
	trace("****************updateDB2Variable() start****************");



	global AdminConfig;
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	trace("scopeId:"+scopeId);
	
	mapList=wsadminToList(AdminConfig.list("VariableMap", scopeId));
	
	filteredMapList=[];
	for item in mapList:
		item=getExactScopeId(item,cellName,nodeName,serverName, clusterName);
		trace("item:"+item);
		if ( not item==""):
			filteredMapList.append(item);
	#endFor
	
	map =filteredMapList[0];	
	trace("VariableMap id:"+map);
	# check if variable exists in specified scope. 
	# 1. if exists, update the value of the variable
	db2_variable_value="${WAS_INSTALL_ROOT}/jdbcdrivers/DB2";
	db2_variable='DB2_JDBC_DRIVER_PATH';
	trace("Trying to update DB2_JDBC_DRIVER_PATH variable");
	varMapIds = getVariableMapIds (db2_variable,cellName,nodeName,serverName, clusterName);
	if(len(varMapIds) > 0):
		trace("Updating DB2_JDBC_DRIVER_PATH variable");
		setVariableValue(db2_variable,db2_variable_value,cellName,nodeName,serverName, clusterName);
	else:
		pass;
	#endIf

	db2_variable='DB2UNIVERSAL_JDBC_DRIVER_PATH';
	trace("Trying to update DB2UNIVERSAL_JDBC_DRIVER_PATH variable");
	varMapIds = getVariableMapIds (db2_variable,cellName,nodeName,serverName, clusterName);
	if(len(varMapIds) > 0):
		trace("Updating DB2UNIVERSAL_JDBC_DRIVER_PATH variable");
		setVariableValue(db2_variable,db2_variable_value,cellName,nodeName,serverName, clusterName);
	else:
		pass;
	#endIf

	db2_variable='UNIVERSAL_JDBC_DRIVER_PATH';
	trace("Trying to update UNIVERSAL_JDBC_DRIVER_PATH variable");
	varMapIds = getVariableMapIds (db2_variable,cellName,nodeName,serverName, clusterName);
	if(len(varMapIds) > 0):
		trace("Updating UNIVERSAL_JDBC_DRIVER_PATH variable");
		setVariableValue(db2_variable,db2_variable_value,cellName,nodeName,serverName, clusterName);
	else:
		pass;
	#endIf



	trace("****************updateDB2Variable() end****************");
#endDef

def replaceOldEnvironment():
	nodeNameParam = '[-nodeName ' + System.getProperty("local.node") + ']'
		
	print nodeNameParam
	servers = AdminTask.listServers(nodeNameParam).split(System.getProperty("line.separator"));
	print "servers ", servers
		
	for x in servers:
		print "server instance is *********************************** ", x
		serverType = AdminConfig.showAttribute(x, "serverType")
		print "server Type is ", serverType
		if (serverType == "NODE_AGENT"):
			#print "Attributes are ------------------------", AdminConfig.showall(x)
			objectbroker = wsadminToList(AdminConfig.list("ObjectRequestBroker", x))
			print "broker list is ", objectbroker
			for broker in objectbroker:
				print "services ", broker
				properties = wsadminToList(AdminConfig.list("Property", broker))
				for property in properties:
					print "property is", AdminConfig.showall(property)
					name = AdminConfig.showAttribute(property, "name")
					print "name is ", name
					if (name == "com.ibm.ws.orb.services.lsd.StoreActiveServerList"):
						print "found match"
						oldValue = AdminConfig.showAttribute(property, "value")
						newValue = convertProfilePathFrom6xTo70(oldValue)
						newValue = convertPathFrom6xTo70(newValue)
						AdminConfig.modify(property, [['value', newValue]])
					#endIf
				#endFor
			#endFor
		#endIf
	#endFor					
#endDef

def createVariable(variableName,variableValue,cellName,nodeName,serverName, clusterName):
	trace("****************createVariable() start****************");
	
	global AdminConfig;
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	trace("scopeId:"+scopeId);
	
	mapList=wsadminToList(AdminConfig.list("VariableMap", scopeId));
	
	filteredMapList=[];
	for item in mapList:
		trace("item:"+item);
		item=getExactScopeId(item,cellName,nodeName,serverName, clusterName);
		trace("item:"+item);
		if ( not item==""):
			filteredMapList.append(item);
	#endFor
	
	map =filteredMapList[0];	
	trace("VariableMap id:"+map);
	trace("variableName:" + variableName + " variableValue:"+str(variableValue));
	
	# check if the variable exists in specified scope. 
	# 1. if exists, update the value of the variable
	# 2. if not exists, create  the variable.
	varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName);
	if(len(varMapIds) > 0):
		setVariableValue(variableName,variableValue,cellName,nodeName,serverName, clusterName);
	elif (not len(map)==0):
		name = ["symbolicName", variableName];
		value = ["value", variableValue];
		attrs = [name, value];
		
		# create WAS variable.
		AdminConfig.create("VariableSubstitutionEntry", map, attrs );
		AdminConfig.save( );
	else:
		pass;
	#endIf
	
	trace("****************createVariable() end****************");
#endif

#-----------------------------------------------------------------
# Check to see if an action needs to be performed based on profileType
#-----------------------------------------------------------------
def checkProfileType(profileType):
	trace("**************** checkProfileType() start ****************");
	result = False
	nodeType=getNodeType();
	if (profileType == "All"):
		result = True
	elif (profileType == nodeType):
		result = True
	trace("**************** checkProfileType() end:"+ str(result) + " ****************");
	return result
	
#endDef
#------------------------------------------------------------------------------
# check whether the specified application is installed 
#------------------------------------------------------------------------------
def checkApplicationExist(appName):
	trace("**************** checkApplicationExist(" + appName+ ") start ****************");
	result = False
	applications = AdminApp.list().split()
	applications.append('isclite')
	applications.append('cbebrowser')
	for application in applications:
		if (application == appName):
			result = True
			trace("**************** checkApplicationExist() end:"+ str(result) + " ****************");
			return result
	trace("**************** checkApplicationExist() end:"+ str(result) + " ****************");
	return result
#endDef


#-----------------------------------------------------------------
# Update an app
#-----------------------------------------------------------------
def updateApp(profileType, appName, earPath, extraOption):
	trace("**************** updateApp(" + profileType + ","+appName+","+earPath+","+extraOption+") start ****************");
	nodeType=getNodeType();
	
	if ( nodeType == 'managed'):
		trace("  managed node, do not update apps");
	elif ((checkProfileType(profileType) == True) and (checkApplicationExist(appName)== True) ):
		# fullEarPath=getWASHome()+"/"+earPath;
		fullEarPath = resolveEarPath(earPath);
		options = ""
		options += " -operation update"
		options += " -contents \""+fullEarPath+"\""
		if (len(extraOption) > 0):
			options += " "+extraOption
		trace("updating application "+appName+" with options " + options);
		try:
			AdminApp.update( appName, 'app', options)
			trace("application "+appName+" update was successful");
		except:
			trace("application "+appName+" update failed!!");
	#endif
	trace("**************** updateApp() end ****************");
#endDef

#-----------------------------------------------------------------
# Uninstall an app
#-----------------------------------------------------------------
def uninstallApp(profileType, appName, forceBPC):
	trace("**************** uninstallApp("+profileType+","+appName+","+forceBPC+") start ****************");
	if ((checkProfileType(profileType) == True) and (checkApplicationExist(appName) == True)):
		options = ""
		if (forceBPC == "forceBPC"):
			options = "-custom forceUninstallBPCApp=true"
		trace("uninstalling application "+appName+" with options "+options);
		try:
			AdminApp.uninstall(appName, options)
			trace("uninstall application "+appName+" was successful");
		except:
			trace("uninstall application "+appName+" failed. Application may not be installed.");
	#endif	
	trace("**************** uninstallApp() end ****************");
#endDef


#-----------------------------------------------------------------
# migrate Applications listed in a txt file
#-----------------------------------------------------------------
def processAppActionsFile(appFileName):
	trace("**************** processAppActionsFile() start ****************");
	
	# read the file
	trace("appFileName="+appFileName);
	
	appFile=open(appFileName, 'r');
	lines = appFile.readlines();
	lineNum = 0
	for line in lines:
		trace(line);
		lineNum = lineNum + 1
		fields = line.split()
		if (len(fields) > 0):
			if (fields[0] == "updateIfInstalled"):
				extraOption = ""
				if (len(fields) > 4):
					extraOption = fields[4]
				#field1 - managed, unmanaged, All, field2 appname field3 location of the ear
				updateApp(fields[1], fields[2], fields[3], extraOption)
			elif (fields[0] == "uninstall"):
				forceFlag = ""
				if (len(fields) > 3):
					forceFlag = fields[3]
				uninstallApp(fields[1], fields[2], forceFlag)
			
	appFile.close()
	trace("**************** processAppActionsFile() end ****************");
#endDef

#-----------------------------------------------------------------
# migrate Applications
#-----------------------------------------------------------------
def migrateApps():
	trace("**************** migrateApps() start ****************");
	
	applications = AdminApp.list().split()
	trace("  Found applications: ");
	for application in applications:
		trace("   "+application);
	
	# read the file
	appActionsDir =  getWASHome() + "/util/migration/700/applications";
	trace("appActionsDir="+appActionsDir);
	
	files = os.listdir(appActionsDir)
	for filename in files:
		#if ends with .txt
		if (filename.endswith(".txt")):
			fullFileName=appActionsDir + "/" + filename
			trace("Found appActions file: " + fullFileName);
			processAppActionsFile(fullFileName)
		#endIf
	#endfor
	
	trace("**************** migrateApps() end ****************");
#endDef

#-----------------------------------------------------------------
# Updates serverindex.xml file with new host name needed only for remote migration
#-----------------------------------------------------------------
def updateServerIndexIds (cellName,nodeName,serverName,clusterName,oldHostName,newHostName):
	global AdminConfig;
	
	serverIndexIds=[];
	print ("****************updateServerIndexIds() start****************");
	print ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName + "##clusterName" + clusterName);
	
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	serverIndexLists = wsadminToList(AdminConfig.list("ServerIndex",scopeId));
	for eachList in serverIndexLists :
		mainHostName=AdminConfig.showAttribute(eachList, "hostName");
		print ("the value for hostName is '" + str(mainHostName) + "'");
		if (mainHostName == oldHostName):
			attribute=[['hostName', newHostName]];
			AdminConfig.modify(eachList, attribute);
			AdminConfig.save();
		#endIf
		entries = wsadminToList(AdminConfig.list("ServerEntry", eachList));
		for entry in entries:
			serverList = wsadminToList(AdminConfig.list("NamedEndPoint", entry));
			for server in serverList:
				endPointList = wsadminToList(AdminConfig.list("EndPoint", server));
				for endPoint in endPointList:
					# get exact variable which is only located in  cell ,node or server level.
					endPoint=getExactScopeId(endPoint,cellName,nodeName,serverName, clusterName);
			
					if ( endPoint !=""):
						hostName = AdminConfig.showAttribute(endPoint, "host");
						print ("The value of host is '" + str(hostName) + "'");
						print ("server:"+endPoint);
						if (hostName == oldHostName):
							attribute=[['host', newHostName]];
							AdminConfig.modify(endPoint, attribute);
							AdminConfig.save();
						#endIf

					#endIf
				#endFor
			#endFor
		#endFor
	#endFor
	trace("****************updateServerIndexIds() end****************");
#endDef


#-----------------------------------------------------------------
# gets a WAS variable from variables.xml at cell scope
#-----------------------------------------------------------------
def getCellVariableValue(variableName, cellName):
	global AdminConfig;
	variableMapIds=[];
	trace("**************** getCellVariableValue() start ****************");
	trace("Variable to get: "+variableName);
	trace ("Scope: ##cellName:"+cellName);
	
	scopeId=getScopeId(cellName,'','','');

	trace("scopeId gotten: " + scopeId);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,'','','');
			
			if (entry !=""):
				name = AdminConfig.showAttribute(entry, "symbolicName")
				trace("name is: " + name);
				
				try:
					value = AdminConfig.showAttribute(entry, "value")
  					trace("current value is: " + value);
				except:
					trace("no value attribute found, skipping")
					continue
					
				# Is this the variable we are looking for
				if (name == variableName):
					return value
				#endIf
			#endIf
		#endFor entry
	#endFor eachList
#endDef

def updateVariable(entry, name, newValue):
	global AdminConfig;
	trace("Setting " + name + " to:  " + newValue);
	attribute=[['value', newValue]];
	AdminConfig.modify(entry, attribute);
	AdminConfig.save();
#endDef

#-----------------------------------------------------------------
# updates variables.xml at node scope
#-----------------------------------------------------------------
def updateNodeVariables(cellName,nodeName):
	global AdminConfig;
	
	savedProps = getSavedProperties()
	
	
	variableMapIds=[];
	trace("**************** updateNodeVariables() start ****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName);
	
	scopeId=getScopeId(cellName,nodeName,'','');

	trace("scopeId gotten: " + scopeId);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,'','');
			
			if (entry !=""):
				name = AdminConfig.showAttribute(entry, "symbolicName")
				trace("name is: " + name);
				
				try:
					value = AdminConfig.showAttribute(entry, "value")
  					trace("current value is: " + value);
				except:
					trace("no value attribute found, skipping")
					continue
								
				# update all variables that still have the source install root
				# to ${WAS_INSTALL_ROOT}
				if ((name != "WAS_INSTALL_ROOT") and (name != "USER_INSTALL_ROOT")):
					savedValue = getSavedValue(savedProps, name)
					if (len(savedValue) > 0):
						updateVariable(entry, name, savedValue)
					#endIf
				#endIf
			#endIf
		#endFor
	#endFor
	trace("**************** updateNodeVariables() end ****************");
#endDef

#-----------------------------------------------------------------
# updates variables.xml at cell scope
#-----------------------------------------------------------------
def updateCellVariables(cellName):
	global AdminConfig;
	
	savedProps = getSavedProperties()
	
	variableMapIds=[];
	trace("**************** updateCellVariables() start ****************");
	trace ("Scope: ##cellName:"+cellName);
	
	scopeId=getScopeId(cellName,'','','');

	trace("scopeId gotten: " + scopeId);
	
	# get WAS_HOME directory
	wasHome = getWASHome();
	
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,'','','');
			
			if (entry !=""):
				name = AdminConfig.showAttribute(entry, "symbolicName")
				trace("name is: " + name);
				
				try:
					value = AdminConfig.showAttribute(entry, "value")
  					trace("current value is: " + value);
				except:
					trace("no value attribute found, skipping")
					continue

				# update cell level icu_data on zOS
				if (name == "WAS_DAEMON_ONLY_ICU_DATA"):
					savedValue = getSavedValue(savedProps, 'Cell_Level_WAS_DAEMON_ONLY_ICU_DATA')
					if (len(savedValue) > 0):
						updateVariable(entry, name, savedValue)
					#endIf
				#endIf
			#endIf
		#endFor
	#endFor
	trace("**************** updateCellVariables() end ****************");
#endDef

def existsPath(pathName):
	newPath=File(pathName);
	return newPath.exists();
#endDef
def getSavedProperties():
	trace("****************getSavedProperties() start****************");
	savedVars={}
	source = getPropertyValue("wbi.upgrade.preserve.file")
	
	# return empty dict if file name is not set
	if (len(source) < 1):
		return savedVars
	
	sourceFile=open(source,"r");
	if( (existsPath(source)==0) or (existsPath(source)==0)):
		trace("migration failed because it cannot find the file "+source);
	else:
		
		srclines=sourceFile.readlines();
		sourceFile.close();
		
		for srcline in srclines :
			trace(srcline)
			if (not srcline.startswith("#")):
				words=srcline.split("=",1);
				if (len(words)==2):
					savedVars[words[0].strip()] = words[1].strip()
				#endif
			#endif
		#endFor
		
		for k,v in savedVars.items():
			trace( k + " : " + v)
		#endFor
	#endIf
		
	trace("****************getSavedProperties() end****************");
	return savedVars;
#endDef

def getSavedValue(savedVars, key):
	trace("****************getSavedValue() start ****************");
	trace("look for "+ key)
	savedValue=""
	if (isZOS() == 1):
		if (savedVars.has_key(key)):
			savedValue = savedVars[key]
		#endIf
	#endIf
	trace(" savedValue: " + savedValue)
	trace("****************getSavedValue() end ****************");
	return savedValue
#endDef


#-----------------------------------------------------------------
# Update WAS and WBI variables (variables.xml)
#-----------------------------------------------------------------
def fixJVMProcDefs():
	global AdminConfig
	trace("**************** fixJVMProcDefs() start ****************");
	
	savedVars = getSavedProperties()

	
	osType = java.lang.System.getProperty("os.name");
	trace("##osType="+osType);
	
	#profile type judgment
	nodeType=getNodeType();
	profileLevel="";
	trace("nodeType = " + nodeType);
	if ( nodeType == 'managed' or nodeType == 'unmanaged' ):
		# standalone profile and custom profile
		cellName=getCellName();
		nodeName=getNodeName();
		profileLevel="node";
	else:
		# dmgr profile
		cellName=getCellName();
		nodeName=getNodeName();
		profileLevel="cell";
	#endIf
		
		
	serverNameList = []
	nodeId = getScopeId(cellName, nodeName, '', '')
	print "nodeId is: " + str(nodeId)
	if(nodeId == ''):
		return
		
	
	controlProcName = ''
	servantProcName = ''
	adjunctProcName = ''	
	nodeShortName = ''
	cellShortName = ''

		
	controlProcName = getSavedValue(savedVars, 'WAS_DEFAULT_CONTROL_PROC_NAME')
	servantProcName = getSavedValue(savedVars, 'WAS_DEFAULT_SERVANT_PROC_NAME')
	adjunctProcName = getSavedValue(savedVars, 'WAS_DEFAULT_ADJUNCT_PROC_NAME')	
	nodeShortName = getSavedValue(savedVars, 'WAS_SERVER_ONLY_node_short_name')

	# get cellName from cell level variable
	cellShortName = getCellVariableValue('WAS_SERVER_ONLY_cell_short_name',cellName)
	
	serverList = wsadminToList(AdminConfig.list('Server',nodeId))
	for server in serverList:
		processDefList = wsadminToList(AdminConfig.list('JavaProcessDef', server))
		serverShortName = ''
		serverShortName = AdminConfig.showAttribute(server, 'shortName')
		# serverShortName = getServerShortName(cellName, nodeName, )
		
		trace( 'serverShortName = ' + str(serverShortName))
		for processDef in processDefList: 
			processType = AdminConfig.showAttribute(processDef, 'processType')
			
			if (processType=="Control"):
				#For control process, update startCommand, stopCommand, and startCommandArgsValue
				trace('Updating Control process')
				if ((len(controlProcName) > 0) and (len(serverShortName) > 0) and (len(cellShortName) > 0) and (len(nodeShortName) > 0)):
					startCommandValue = 'START ' + controlProcName
					stopCommandValue = 'STOP ' + serverShortName + ';CANCEL ' + serverShortName				
					startCommandArgsValue='JOBNAME='+serverShortName+',ENV='+cellShortName+'.'+nodeShortName+'.'+serverShortName
					terminateCommandValue='FORCE ' + serverShortName
					updates=[['startCommand', startCommandValue], ['stopCommand', stopCommandValue],['startCommandArgs',startCommandArgsValue],['terminateCommand',terminateCommandValue]];
					trace(' modifying: ' + str(updates))
					AdminConfig.modify(processDef,updates)
				else:
					trace(' WARNING: tried to update a Control process, but WAS_DEFAULT_CONTROL_PROC_NAME, server shortName, WAS_SERVER_ONLY_cell_short_name, or WAS_SERVER_ONLY_node_short_name is undefined, check JVM process definition')
					
			elif (processType=='Servant'):
				#For servant process, update startCommand
				trace('Updating Servant process')
				if (len(servantProcName) > 0 ):				
					startCommandValue = servantProcName
					updates=[['startCommand', startCommandValue]];
					trace(' modifying: ' + str(updates))
					AdminConfig.modify(processDef,updates)
				else:
					trace(' WARNING: tried to update a Servant process, but no WAS_DEFAULT_SERVANT_PROC_NAME defined, check JVM process definition')
					
			elif (processType=='Adjunct'):
				#For adjunct process, update startCommand
				trace('Updating Adjunct process')
				if (len(adjunctProcName) > 0):
					startCommandValue = adjunctProcName
					updates=[['startCommand', startCommandValue]];
					trace(' modifying: ' + str(updates))
					AdminConfig.modify(processDef,updates)
				else:
					trace(' WARNING: tried to update a Adjunct process, but no WAS_DEFAULT_ADJUNCT_PROC_NAME defined, check JVM process definition')
				
			#endIf
		#endFor processDefinitions
	#endFor servers
	
	trace("**************** fixJVMProcDefs() end ****************");
#endDef


#-----------------------------------------------------------------
# Main program:
#-----------------------------------------------------------------
def main():
	#global framework
	#framework.log("debug", "MigrationCommon.py", "MigrationCommon.py", "Executing migration common script."
	#TODO just for debug remove later
	#System.setProperty("bpm.upgrade.previous.profileName", "Dmgr01");
	#System.setProperty("wbi.upgrade.node.type", "dmgr");
	#System.setProperty("wbi.upgrade.backup.dir", "c:/back");
	#System.setProperty("wbi.upgrade.previous.version", "6.2.0.3");
	#System.setProperty("bpm.upgrade.cluster.name", "default.AppTarget");
	#System.setProperty("bpm.upgrade.cluster.stamp", "true");

	oldHostName =System.getProperty("bpm.upgrade.previous.hostName");
	newHostName =System.getProperty("bpm.upgrade.current.hostName");
	serverName='';
	clusterName=System.getProperty("bpm.upgrade.cluster.name");
	if(clusterName):
		trace(clusterName)
	else:
		clusterName = ''
	#endIf
	clusterStamp=System.getProperty("bpm.upgrade.cluster.stamp");
	previousVersion = getPropertyValue('wbi.upgrade.previous.version')
	
	if (clusterStamp != "true"):
		migratedWPSHome=normalizePath(getMigratedWASHome());
		migratedWPSHome=migratedWPSHome.replace('\\',"/");
		migratedProfileHome=normalizePath(getMigratedProfileHome());
		migratedProfileHome=migratedProfileHome.replace('\\',"/");
	#endIf	

	cellName=getCellName();
	nodeType=getNodeType();


	if ( nodeType == 'managed' or nodeType == 'unmanaged' ):
		# standalone profile and custom profile
		nodeName=getNodeName();
		createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
	else:
		# dmgr profile
		nodeName='';
		if (clusterStamp != "true"):
			trace("Calling replaceOldInstallRoot at cell level for oldInstall value: " + migratedWPSHome);
			replaceOldProfileRoot(migratedProfileHome,cellName,nodeName,serverName, clusterName);
			replaceOldInstallRoot(migratedWPSHome,cellName,nodeName,serverName, clusterName);
			# set the node name to the actual value again to call replace for node level variables
			nodeName=getNodeName();
			#reset the version to previous value
			if (clusterName != ''):
				createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
			#create the variable for each cluster in dmgr
			else:
				createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
				clusterList = wsadminToList(AdminConfig.list("ServerCluster"))
				for cluster in clusterList:
					print "Cluster is ", cluster
					name = AdminConfig.showAttribute(cluster, "name")
					print "Name is", name
					createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, name);
				#endFor
			#endFor
		#endIf
		#Just create the variable when called for cluster stamping
		if (clusterStamp == "true"):
			nodeName=getNodeName();
			createVariable("MIGRATION_VERSION", "7.5.0.0", cellName, nodeName, serverName, clusterName);
			return;
		#endIf
	#endIf

	#This is to replace the entries in nodeagents server.xml file
	if (nodeType == 'managed'):
		replaceOldEnvironment();

	if (oldHostName):
		updateServerIndexIds(cellName,nodeName,serverName,clusterName,oldHostName, newHostName);
	#endIf

	trace("Calling replaceOldInstallRoot at node level for oldInstall value: " + migratedWPSHome);
	replaceOldProfileRoot(migratedProfileHome,cellName,nodeName,serverName, clusterName);
	replaceOldInstallRoot(migratedWPSHome,cellName,nodeName,serverName, clusterName);
	print 'Done replacing old install values.'

	updateDB2Variables(cellName, nodeName, serverName, clusterName);
	#update DB2Variable at cell scope
	print 'Updating DB2 variables for cell scope.'
	updateDB2Variables(cellName, '', '', '');
	print 'Done updating DB2 variables.'
	if (getNodeType() != 'managed'):
		updateAllOracleDataSource();
	#endIf

	trace("getNodeType() " + getNodeType());
	if (getNodeType() == 'unmanaged'):
		updateDerbyDataSourceProperties();
	#endIf
	#updateAllSQLServerDataSource();

	if (clusterName == ''):
		if (isZOS() == 1):
			updateNodeVariables(cellName, nodeName);
			updateCellVariables(cellName);
			if (fixJVMProcDefs() == 0):
				print 'Failed during migration process for zOS platform. Please check the log files'
			#endIf
		#endIf
	#endIf

	#if (previousVersion.find('6.0.2')>=0):
	#	print 'Found 602 source profile. Trying to update variables.'
	#	updateWBIVariables();
	#	print 'Updated wbi variable. Exiting migration common script.'
	#	return 0
	#else:
	#	print 'Not a 602 source profile. No updates needed. Exiting migration common script.'
	#	return 0
	#endIf
	#migrateApps();
	
#endDef

def updateDerbyDataSourceProperties():
	trace("****************updateDataSourceProperties() start****************");
	
	dataSourceId="";
	providerType="Derby JDBC Provider";
	providerType1="Derby JDBC Provider (XA)";
	providerType2="Cloudscape JDBC Provider";
	providerType3="Cloudscape JDBC Provider (XA)";

	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		trace(AdminConfig.showAttribute(id,"providerType"));
		if((curAttVal1==providerType) or (curAttVal1==providerType1) or (curAttVal1==providerType2) or (curAttVal1==providerType3)):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Debry found" + name);
			propSet = AdminConfig.showAttribute(id,"propertySet")
			resoucepropertiesList = wsadminToList(AdminConfig.list("J2EEResourceProperty", propSet))
			for propid in resoucepropertiesList:
				curPropName=AdminConfig.showAttribute(propid,"name");
				if (curPropName=="databaseName"):
					trace("original propertyValue:"+AdminConfig.showAttribute(propid,"value"));
					existingValue = AdminConfig.showAttribute(propid,"value");
					#find the old profile value
					index = existingValue.find("databases");
					if (index != -1):
						str = existingValue[index:len(existingValue)]
						trace("string value to be added is " + str);
						newValue = "${USER_INSTALL_ROOT}/" + str;				
						trace("updated propertyValue:"+newValue);	
						properties = [["value", newValue]];
						AdminConfig.modify(propid, properties)
						AdminConfig.save()
					#endIf
				#endIf
			#endFor
		#endIf
	#endFor
	trace("****************updateDataSourceProperties() end****************");
#endif

def updateAllOracleDataSource():
	trace("****************updateAllOracleDataSources() start****************");
	
	dataSourceId="";
	providerType="Oracle JDBC Driver";
	providerType1="Oracle JDBC Driver (XA)";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		if((curAttVal1==providerType) or (curAttVal1==providerType1)):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Oracle found" + name);
			provider=AdminConfig.showAttribute(id,"provider");
			trace("After provider" + AdminConfig.showAttribute(provider, "name"));
			print AdminConfig.showAttribute(provider, "classpath");
			oldClassPath = AdminConfig.showAttribute(provider, "classpath");
			#extract the path that needs to be replaced
			oldClassPath.replace("\\","/");
			newClassPath = "ojdbc6.jar"
			if (oldClassPath.find("/") != -1):
				index = oldClassPath.find("/");
				print "index before", index;
				prevIndex = index;
				while (index!=-1):
					prevIndex = index;
					oldClassPath = oldClassPath[index+1:len(oldClassPath)]
					index = oldClassPath.find("/");
					print "index", index
				#endWhile
				originalValue = AdminConfig.showAttribute(provider, "classpath");
				newClassPath = originalValue[0:prevIndex+1]+"ojdbc6.jar";
			#endIf
			attributes=[["classpath",'']];
			AdminConfig.modify(provider, attributes );
			#newClassPath="${ORACLE_JDBC_DRIVER_PATH}/ojdbc6.jar";
			trace("new classpath being set" + newClassPath);	
			attributes=[["classpath",newClassPath]];
			AdminConfig.modify(provider, attributes );
			AdminConfig.save();

			curPropName=AdminConfig.showAttribute(id,"datasourceHelperClassname");
			properties = [["datasourceHelperClassname", "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"]];
			trace("original propertyValue:"+AdminConfig.showAttribute(id,"datasourceHelperClassname"));
			trace("updated propertyValue:"+"com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper");	
			AdminConfig.modify(id, properties)
			AdminConfig.save()
		#endIf
	#endFor
	
	trace("****************updateAllOracleDataSources() end****************");
#endDef


def updateAllSQLServerDataSource():
	trace("****************updateAllSQLServerDataSource() start****************");
	
	dataSourceId="";
	providerType="SQLServer";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		if(curAttVal1==providerType):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Oracle found" + name);
			provider=AdminConfig.showAttribute(id,"provider");
			newClasspath="${MICROSOFT_JDBC_DRIVER_PATH}/sqljdbc.jar";
			trace("new classpath being set" + newClasspath);	
			attributes = [["classpath",newClasspath]];
			AdminConfig.modify(id, attributes );
			AdminConfig.save();

			curPropName=AdminConfig.showAttribute(id,"datasourceHelperClassname");
			properties = [["datasourceHelperClassname", "com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper"]];
			trace("original propertyValue:"+AdminConfig.showAttribute(id,"datasourceHelperClassname"));
			trace("updated propertyValue:"+"com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper");	
			AdminConfig.modify(id, properties)
			AdminConfig.save()
		#endIf
	#endFor
	
	trace("****************updateAllSQLServerDataSources() end****************");
#endDef

#-----------------------------------------------------------------
# Start Main function
#-----------------------------------------------------------------
main();
#-----------------------------------------------------------------
# End Main function
#-----------------------------------------------------------------